@@ -19,7 +19,11 @@
  * */
 
 #include <qpushbutton.h>
-#include <qprocess.h>
+#include <q3process.h>
+//Added by qt3to4:
+#include <Q3TextStream>
+#include <Q3HBoxLayout>
+#include <Q3VBoxLayout>
 
 #include <unistd.h>
 #include <stdlib.h>
@@ -36,7 +40,7 @@ using namespace std;
 AusearchProcess::AusearchProcess(QWidget *parent, const char *name): QDialog(parent, name)
 {
 	setCaption(tr("Ausearch Process"));
-	textEdit1 = new QTextEdit(this);
+	textEdit1 = new Q3TextEdit(this);
 	textEdit1->setPaletteBackgroundColor(QColor(250,180,200));
         textEdit1->resize( 600, 100 );
 
@@ -45,9 +49,9 @@ AusearchProcess::AusearchProcess(QWidget *parent, const char *name): QDialog(par
 	connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
 	closeButton->setDefault(true);
 
-	mainLayout = new QVBoxLayout(this);
-	upperLayout = new QVBoxLayout;
-	footLayout = new QHBoxLayout;
+	mainLayout = new Q3VBoxLayout(this);
+	upperLayout = new Q3VBoxLayout;
+	footLayout = new Q3HBoxLayout;
 	
 	mainLayout->setMargin(11);
 	upperLayout->addWidget(textEdit1);
@@ -114,8 +118,8 @@ void AusearchProcess::readFromOutputFile(QString ausearch_str_pp_str)
 			name = *it_d;
 			file_interface_name = dir_name + forward_slash + name;
 			QFile file( file_interface_name );
-			if ( file.open( IO_ReadOnly ) ) {
-				QTextStream stream( &file );
+			if ( file.open( QIODevice::ReadOnly ) ) {
+				Q3TextStream stream( &file );
 				////////////////////////////////////////////
 				//int i,j,k,l,m,n;	
 				if(order_x == 1)
