@@ -21,7 +21,11 @@
 #include <qlayout.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
+#include <q3textedit.h>
+//Added by qt3to4:
+#include <Q3TextStream>
+#include <Q3HBoxLayout>
+#include <Q3VBoxLayout>
 
 #include <unistd.h>
 #include <stdlib.h>
@@ -43,7 +47,7 @@ AutoRelabel::AutoRelabel(QWidget *parent, const char *name): QDialog(parent, nam
 	textEdit1->setPaletteBackgroundColor(QColor(0,254,100));
 */
 
-	timeButtonGroup = new QButtonGroup(this);
+	timeButtonGroup = new Q3ButtonGroup(this);
 	timeButtonGroup->resize( 200, 200 );
 	nowRadioButton = new QRadioButton(tr("now"), timeButtonGroup);
 	nextbootRadioButton = new QRadioButton(tr("nextboot"), timeButtonGroup);
@@ -62,15 +66,15 @@ AutoRelabel::AutoRelabel(QWidget *parent, const char *name): QDialog(parent, nam
 
 	//autorelabel_base_process();
 
-	mainLayout = new QVBoxLayout(this);
+	mainLayout = new Q3VBoxLayout(this);
 	mainLayout->setMargin(11);
 /*
 	upperLayout = new QVBoxLayout;
 	upperLayout->addWidget(textEdit1);
 */
-	middleLayout = new QVBoxLayout;
-	rightLayout = new QHBoxLayout;
-	leftLayout = new QHBoxLayout;
+	middleLayout = new Q3VBoxLayout;
+	rightLayout = new Q3HBoxLayout;
+	leftLayout = new Q3HBoxLayout;
 	//thirdLayout = new QHBoxLayout;
 	
 	//rightLayout->addStretch();
@@ -82,7 +86,7 @@ AutoRelabel::AutoRelabel(QWidget *parent, const char *name): QDialog(parent, nam
 	middleLayout->addLayout(rightLayout);
 	//middleLayout->addLayout(thirdLayout);
 
-	footLayout = new QHBoxLayout;
+	footLayout = new Q3HBoxLayout;
 	footLayout->addStretch();
 	footLayout->addWidget(closeButton);
 
@@ -245,8 +249,8 @@ void AutoRelabel::readFromOutputFile()
 			QRegExp rx_false("false");
 			QRegExp rx_sync("sync");
 			*/
-			if ( file.open( IO_ReadOnly ) ) {
-				QTextStream stream( &file );
+			if ( file.open( QIODevice::ReadOnly ) ) {
+				Q3TextStream stream( &file );
 				////////////////////////////////////////////
 				//int i,j,k,l,m,n;	
 				if(order_x == 1)
