@@ -1,7 +1,7 @@
 /*
  * segatex SELinux tool.
  *
- * Copyright (C) 2007-2008 Shintaro Fujiwara 
+ * Copyright (C) 2007-2009 Shintaro Fujiwara 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,7 +37,8 @@ int main(int argc, char *argv[])
 				"/root/segatex");
 	app.installTranslator(&appTranslator);
 	//QSplashScreen *splash = new QSplashScreen(QPixmap::fromMimeSource("/root/segatex/splash.png"));
-	QPixmap splashIcon = QPixmap(":/document.png");
+	//QPixmap splashIcon = QPixmap(":/document.png");
+	QPixmap splashIcon = QPixmap(":/root/segatex/splash.png");
 	QSplashScreen *splash = new QSplashScreen(splashIcon);
 
 	splash->show();
