@@ -20,10 +20,15 @@
 
 #include <qlayout.h>
 #include <qpushbutton.h>
-#include <qprocess.h>
+#include <q3process.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
+#include <q3textedit.h>
 #include <qregexp.h>
+//Added by qt3to4:
+#include <Q3TextStream>
+#include <Q3HBoxLayout>
+#include <QLabel>
+#include <Q3VBoxLayout>
 
 #include <unistd.h>
 #include <stdlib.h>
@@ -40,7 +45,7 @@ using namespace std;
 SemanageCoreFcontextProcess::SemanageCoreFcontextProcess(QWidget *parent, const char *name): QDialog(parent, name)
 {
 	setCaption(tr("Semanage Fcontext Process"));
-	textEdit1 = new QTextEdit(this);
+	textEdit1 = new Q3TextEdit(this);
 	textEdit1->setPaletteBackgroundColor(QColor(250,180,200));
 
 	semanageEditLabel = new QLabel(tr("fcontext:"), this );
@@ -91,7 +96,7 @@ SemanageCoreFcontextProcess::SemanageCoreFcontextProcess(QWidget *parent, const
 	modifyButton->setPaletteBackgroundColor(QColor(100,200,200));
 	connect(modifyButton, SIGNAL(clicked()), this, SLOT(modify_button_clicked()));
 
-        filetypeButtonGroup = new QButtonGroup(this);
+        filetypeButtonGroup = new Q3ButtonGroup(this);
         filetypeButtonGroup->resize( 400, 400 );
         allfilesRadioButton = new QRadioButton(tr("all files"), filetypeButtonGroup);
         regularfileRadioButton = new QRadioButton(tr("regular file"), filetypeButtonGroup);
@@ -119,17 +124,17 @@ SemanageCoreFcontextProcess::SemanageCoreFcontextProcess(QWidget *parent, const
 	//set textEdit smanage such and such -l
 	semanage_core_base_fcontext_process();
 
-	mainLayout = new QVBoxLayout(this);
+	mainLayout = new Q3VBoxLayout(this);
 	mainLayout->setMargin(11);
 
-	upperLayout = new QVBoxLayout;
+	upperLayout = new Q3VBoxLayout;
 	upperLayout->addWidget(textEdit1);
 
-	middleLayout = new QVBoxLayout;
-	leftLayout = new QHBoxLayout;
-	rightLayout = new QHBoxLayout;
-	thirdLayout = new QHBoxLayout;
-	fourthLayout = new QHBoxLayout;
+	middleLayout = new Q3VBoxLayout;
+	leftLayout = new Q3HBoxLayout;
+	rightLayout = new Q3HBoxLayout;
+	thirdLayout = new Q3HBoxLayout;
+	fourthLayout = new Q3HBoxLayout;
 	
 	leftLayout->addWidget(semanageEditLabel);
 	leftLayout->addWidget(semanageEditLineEdit);
@@ -159,7 +164,7 @@ SemanageCoreFcontextProcess::SemanageCoreFcontextProcess(QWidget *parent, const
 	middleLayout->addLayout(thirdLayout);
 	middleLayout->addLayout(fourthLayout);
 
-	footLayout = new QHBoxLayout;
+	footLayout = new Q3HBoxLayout;
 	footLayout->addStretch();
 	footLayout->addWidget(closeButton);
 
@@ -295,7 +300,9 @@ if(namedpipeRadioButton->isChecked()){
 	
 	//Now, let's restorecon path
 	semanageEditLineEdit_str_add_restorecon = "restorecon -R -v " + restorecon_str;
-	cout << "semanageEditLineEdit_str_add_restorecon:" << semanageEditLineEdit_str_add_restorecon << endl;
+	//for debug
+	//cout << "semanageEditLineEdit_str_add_restorecon:" << semanageEditLineEdit_str_add_restorecon << endl;
+	//
         #define PWD_BUF 8600
         const char* restorecon_file="/root/segatex/semanage/add_fcontexted_restorecon";
         ofstream os_add_restorecon;
@@ -638,8 +645,8 @@ void SemanageCoreFcontextProcess::readFromOutputFile()
 			name = *it_d;
 			file_interface_name = dir_name + forward_slash + name;
 			QFile file( file_interface_name );
-			if ( file.open( IO_ReadOnly ) ) {
-				QTextStream stream( &file );
+			if ( file.open( QIODevice::ReadOnly ) ) {
+				Q3TextStream stream( &file );
 				////////////////////////////////////////////
 				//int i,j,k,l,m,n;	
 				if(order_x == 1)
