@@ -20,11 +20,16 @@
 
 #include <qlayout.h>
 #include <qpushbutton.h>
-#include <qprocess.h>
+#include <q3process.h>
 #include <qradiobutton.h>
-#include <qbuttongroup.h>
+#include <q3buttongroup.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
+#include <q3textedit.h>
+//Added by qt3to4:
+#include <Q3TextStream>
+#include <Q3HBoxLayout>
+#include <QLabel>
+#include <Q3VBoxLayout>
 //#include <qprocess.h>
 
 #include <unistd.h>
@@ -43,7 +48,7 @@ using namespace std;
 SemanageCoreTranslationProcess::SemanageCoreTranslationProcess(QWidget *parent, const char *name): QDialog(parent, name)
 {
 	setCaption(tr("Semanage Translation Process"));
-	textEdit1 = new QTextEdit(this);
+	textEdit1 = new Q3TextEdit(this);
 	textEdit1->setPaletteBackgroundColor(QColor(250,180,200));
 
 	semanageEditLabel = new QLabel(tr("Add translation(translation_name):"), this );
@@ -90,16 +95,16 @@ SemanageCoreTranslationProcess::SemanageCoreTranslationProcess(QWidget *parent,
 	//set textEdit smanage such and such -l
 	semanage_core_base_translation_process();
 
-	mainLayout = new QVBoxLayout(this);
+	mainLayout = new Q3VBoxLayout(this);
 	mainLayout->setMargin(11);
 
-	upperLayout = new QVBoxLayout;
+	upperLayout = new Q3VBoxLayout;
 	upperLayout->addWidget(textEdit1);
 
-	middleLayout = new QVBoxLayout;
-	leftLayout = new QHBoxLayout;
-	rightLayout = new QHBoxLayout;
-	thirdLayout = new QHBoxLayout;
+	middleLayout = new Q3VBoxLayout;
+	leftLayout = new Q3HBoxLayout;
+	rightLayout = new Q3HBoxLayout;
+	thirdLayout = new Q3HBoxLayout;
 	
 	leftLayout->addWidget(semanageEditLabel);
 	leftLayout->addWidget(semanageEditLineEdit);
@@ -121,7 +126,7 @@ SemanageCoreTranslationProcess::SemanageCoreTranslationProcess(QWidget *parent,
 	middleLayout->addLayout(rightLayout);
 	middleLayout->addLayout(thirdLayout);
 
-	footLayout = new QHBoxLayout;
+	footLayout = new Q3HBoxLayout;
 	footLayout->addStretch();
 	footLayout->addWidget(closeButton);
 
@@ -187,7 +192,10 @@ void SemanageCoreTranslationProcess::add_button_clicked_process(QString semanage
 void SemanageCoreTranslationProcess::delete_button_clicked_process(QString semanageEditLineEdit3_str, QString semanageEditLineEdit7_str)
 {
 	semanageEditLineEdit_str_pp = "semanage translation -d -T " + semanageEditLineEdit3_str + " " + semanageEditLineEdit7_str;
-cout << "semanageEditLineEdit_str_pp:" << semanageEditLineEdit_str_pp << endl;
+	//for debug
+	//cout << "semanageEditLineEdit_str_pp:" << semanageEditLineEdit_str_pp << endl;
+	//
+
         #define PWD_BUF 8600
         const char* make_module_file="/root/segatex/semanage/delete_translationed";
         ofstream os_delete;
@@ -303,8 +311,8 @@ void SemanageCoreTranslationProcess::readFromOutputFile()
 			name = *it_d;
 			file_interface_name = dir_name + forward_slash + name;
 			QFile file( file_interface_name );
-			if ( file.open( IO_ReadOnly ) ) {
-				QTextStream stream( &file );
+			if ( file.open( QIODevice::ReadOnly ) ) {
+				Q3TextStream stream( &file );
 				////////////////////////////////////////////
 				//int i,j,k,l,m,n;	
 				if(order_x == 1)
